- Add displacement operations `left shift (\<\<)
  <xotl.tools.future.datetime.TimeSpan.__lshift__>`:meth: and `right shift (>>)
  <xotl.tools.future.datetime.TimeSpan.__rshift__>`:meth: for
  ``xotl.tools.future.datetime.TimeSpan``.

- Add ``xoutil.objects.smart_getter`` and ``xoutil.objects.save_attributes``.

- Document experimental module ``xoutil.tasking``.

- Add extra (and experimental) module ``xoutil.testing``.
